@@ -246,11 +246,13 @@ class ReconnectingWebSocket:
                 data = json.loads(uncompress_data)
             except:
                 data = uncompress_data
+        elif msg.type in (aiohttp.WSMsgType.CLOSE, aiohttp.WSMsgType.CLOSED, aiohttp.WSMsgType.ERROR):
+            logging.error(f"receive invalid msg: {msg}")
+            return None
         else:
             raise HuoBiWebSocketError(f"invalid msg type: {msg.type}")
 
         logging.debug(f"receive msg: {data}")
-
         return data
 
     async def send_heartbeat_msg(self, msg, *args, **kwargs):
